/**
 * Takes a given set of strings and adds/removes them from that set.  If the
 * string value is in the set it is removed.  If it is not in the set then
 * it is added.
 *
 * This is a curried function because why not...
 *
 * @param obj {Set} a set of strings used for the toggle operation
 * @param keys {string} N number of strings to use for the toggle
 * @returns {Set} the updated set of toggled strings.
 */
export declare function toggle(obj: Set<string>): (...keys: string[]) => Set<string>;
/**
 * Takes a given set of strings and adds/removes them from the set if a given
 * condition (predicate) is met.
 * @param obj {Set} a set of strings used for the toggle operation
 * @param predicate {boolean} a boolean condition when true means that the
 * toggle operation will be performed.
 * @param keys {string} N number of strings to use for the toggle
 * @returns {Set} the updated set of toggled strings.
 */
export declare function toggleIf(obj: Set<string>, predicate: boolean): (...keys: string[]) => Set<string>;
/**
 * Takes a given set of strings and adds/removes them from the set if a given
 * condition (predicate) is met.  If it is not met, then a secondary (else) set
 * of strings are added/removed.
 * @param obj {Set} a set of strings used for the toggle operation
 * @param predicate {boolean} a boolean condition when true means that the
 * toggle operation will be performed.
 * @param ifKeys {string} N number of strings to use for the if toggle
 * @param elseKeys {string} N number of strings to use for the else toggle
 * @returns {Set} the updated set of toggled strings.
 */
export declare function toggleIfElse(obj: Set<string>, predicate: boolean): (...ifKeys: string[]) => (...elseKeys: string[]) => Set<string>;
/**
 * Takes a given set of strings and removes them from the input set.
 *
 * @param obj {Set} a set of strings used for the toggle operation
 * @param keys {string} N number of strings that will be removed from the set
 * @returns {Set} the updated set of strings.
 */
export declare function toggleOff(obj: Set<string>): (...keys: string[]) => Set<string>;
/**
 * Takes a given set of strings and removes them from the input set if a given
 * condition (predicate) is met.  If not met, then they are turned on.
 * @param obj {Set} a set of strings used for the toggle operation
 * @param predicate {boolean} a boolean condition when true means that the
 * items will be turned off in the set
 * @param keys {string} N number of strings to use for the toggle
 * @returns {Set} the updated set of toggled strings.
 */
export declare function toggleOffIf(obj: Set<string>, predicate: boolean): (...keys: string[]) => Set<string>;
/**
 * Takes a given set of strings and removes them from the input set if a given
 * condition (predicate) is met.  If not met, then different set of strings are
 * turned off.
 * @param obj {Set} a set of strings used for the toggle operation
 * @param predicate {boolean} a boolean condition when true means that the
 * items will be turned off in the set
 * @param ifKeys {string} N number of strings to use for the if toggle
 * @param elseKeys {string} N number of strings to use for the else toggle
 * @returns {Set} the updated set of toggled strings.
 */
export declare function toggleOffIfElse(obj: Set<string>, predicate: boolean): (...ifKeys: string[]) => (...elseKeys: string[]) => Set<string>;
/**
 * Takes a given set of strings and adds them to the input set.
 *
 * @param obj {Set} a set of strings used for the toggle operation
 * @param keys {string} N number of strings that will be added to the set
 * @returns {Set} the updated set of strings.
 */
export declare function toggleOn(obj: Set<string>): (...keys: string[]) => Set<string>;
/**
 * Takes a given set of strings and adds them to the input set if a given
 * condition (predicate) is met.  If not met, they they are turned off.
 * @param obj {Set} a set of strings used for the toggle operation
 * @param predicate {boolean} a boolean condition when true means that the
 * items will be turned on in the set
 * @param keys {string} N number of strings to use for the toggle
 * @returns {Set} the updated set of toggled strings.
 */
export declare function toggleOnIf(obj: Set<string>, predicate: boolean): (...keys: string[]) => Set<string>;
/**
 * Takes a given set of strings and adds them from the input set if a given
 * condition (predicate) is met.  If not met, then different set of strings are
 * turned on.
 * @param obj {Set} a set of strings used for the toggle operation
 * @param predicate {boolean} a boolean condition when true means that the
 * items will be turned off in the set
 * @param ifKeys {string} N number of strings to use for the if toggle
 * @param elseKeys {string} N number of strings to use for the else toggle
 * @returns {Set} the updated set of toggled strings.
 */
export declare function toggleOnIfElse(obj: Set<string>, predicate: boolean): (...ifKeys: string[]) => (...elseKeys: string[]) => Set<string>;
